{% extends "base.html" %}

{% block content %}
  <article>
    <header>
      <h2>{{ keyword.name }} ({{ keyword.articles|length }})</h2>
    </header>

    <div>
      <ul>
        {% for article in keyword.articles %}
          <li><a href="/numero/{{ article.numero.name }}/article/{{ article.id }}/">{{ article.title_f }}</a></li>
        {% endfor %}
      </ul>
    </div>
  </article>
{% endblock content %}
